@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 
 if __name__ == "__main__":
-  import app
+  from . import app
   app.main()
